@@ -5,6 +5,7 @@ import os.path
 
 import ssg.build_profile
 import ssg.build_yaml
+import ssg.jinja
 import ssg.utils
 import ssg.controls
 import ssg.products
@@ -46,6 +47,7 @@ def create_parser():
     parser.add_argument(
         "--rule-id",
         type=str,
+        default="off",
         help="Creates a profile with the specified rule and does not use other profiles."
         "The profile ID is identical to the rule ID of the selected rule."
         " If you want to process all rules in benchmark of the product, "
@@ -90,7 +92,7 @@ def load_benchmark_source_data_from_directory_tree(loader, env_yaml, product_yam
 
 def dump_compiled_profile(base_dir, profile):
     dest = os.path.join(base_dir, "profiles", "{name}.profile".format(name=profile.id_))
-    profile.dump_yaml(dest)
+    profile.dump_json(dest)
 
 
 def get_all_resolved_profiles_by_id(
@@ -120,6 +122,8 @@ def load_resolve_and_validate_profiles(
 def save_everything(base_dir, loader, controls_manager, profiles):
     controls_manager.save_everything(os.path.join(base_dir, "controls"))
     loader.save_all_entities(base_dir)
+    if not os.path.exists(os.path.join(base_dir, "profiles")):
+        os.makedirs(os.path.join(base_dir, "profiles"))
     for p in profiles:
         dump_compiled_profile(base_dir, p)
 
@@ -155,12 +159,13 @@ def get_relevant_benchmarks(env_yaml, product_yaml):
     return out
 
 
-def get_minimal_profiles_by_id(rules, variables):
+def get_minimal_profiles_by_id(rules):
     out = {}
     for rule in rules:
         data = {
               'documentation_complete': True,
-              'variables': variables,
+              'single_rule_profile': True,
+              'variables': {},
               'selected': [rule],
               'id_': rule,
         }
@@ -176,7 +181,7 @@ def get_profiles_per_rule_by_id(rule_id, project_root_abspath, env_yaml, product
         raise Exception("Rule ID: {} not found!".format(rule_id))
     if "ALL_RULES" not in rule_id:
         rules = {rule_id}
-    return get_minimal_profiles_by_id(rules, {})
+    return get_minimal_profiles_by_id(rules)
 
 
 def main():
@@ -186,6 +191,7 @@ def main():
     project_root_abspath = os.path.abspath(args.project_root)
 
     env_yaml = get_env_yaml(args.build_config_yaml, args.product_yaml)
+    ssg.jinja.initialize(env_yaml)
     product_yaml = ssg.products.Product(args.product_yaml)
 
     product_cpes = ProductCPEs()
@@ -218,17 +224,21 @@ def main():
 
     add_stig_references(args.stig_references, loader.all_rules.values())
 
-    if args.rule_id is None or args.rule_id == "off":
-        profiles_by_id = get_all_resolved_profiles_by_id(
+    if args.rule_id == "ALL_RULES" or args.rule_id == "off":
+        normal_profiles = get_all_resolved_profiles_by_id(
             env_yaml, product_yaml, loader, product_cpes, controls_manager, controls_dir
         )
     else:
-        profiles_by_id = get_profiles_per_rule_by_id(
+        normal_profiles = {}
+    if args.rule_id == "ALL_RULES" or args.rule_id != "off":
+        single_rule_profiles = get_profiles_per_rule_by_id(
             args.rule_id, project_root_abspath, env_yaml, product_yaml
         )
-
+    else:
+        single_rule_profiles = {}
+    profiles = list(normal_profiles.values()) + list(single_rule_profiles.values())
     save_everything(
-        args.resolved_base, loader, controls_manager, profiles_by_id.values())
+        args.resolved_base, loader, controls_manager, profiles)
 
 
 if __name__ == "__main__":
