@@ -3,7 +3,7 @@
 
 
 # use auditctl
-sed -i "s%^ExecStartPost=.*%ExecStartPost=-/sbin/auditctl%" /usr/lib/systemd/system/auditd.service
+{{{ setup_auditctl_environment() }}}
 
 
 rm -rf /etc/audit/rules.d/*
@@ -20,3 +20,6 @@ echo "-w /etc/network/ -p wa" >> /etc/audit/audit.rules
 {{% else -%}}
 echo "-w /etc/sysconfig/network -p wa" >> /etc/audit/audit.rules
 {{% endif %}}
+{{% if product in ['ubuntu2404'] %}}
+echo "-w /etc/netplan/ -p wa" >> /etc/audit/audit.rules
+{{% endif %}}
