@@ -2,4 +2,4 @@
 
 {{{ bash_instantiate_variables("var_auditd_disk_full_action") }}}
 
-{{{ bash_replace_or_append("/etc/audit/auditd.conf", '^disk_full_action', "$var_auditd_disk_full_action") }}}
+{{{ bash_replace_or_append("/etc/audit/auditd.conf", '^disk_full_action', "$var_auditd_disk_full_action", cce_identifiers=cce_identifiers) }}}
