@@ -17,4 +17,4 @@
                   insensitive=true,
                   separator=" = ",
                   separator_regex="\s*=\s*",
-                  prefix_regex="^\s*")}}}
+                  prefix_regex="^\s*", rule_id=rule_id)}}}
