@@ -1,9 +1,8 @@
 #!/bin/bash
 # packages = chrony
-#
-# profiles = xccdf_org.ssgproject.content_profile_stig
+# variables = var_time_service_set_maxpoll=16
 
-yum remove -y ntp
+{{{ bash_package_remove("ntp") }}}
 
 # Remove all server or pool options
 sed -i "/^\(server\|pool\).*/d" {{{ chrony_conf_path }}}
