@@ -1,6 +1,9 @@
 #!/bin/bash
-
-# platform = multi_platform_fedora,Red Hat Enterprise Linux 9
+{{% if sshd_distributed_config == "false" %}}
+# platform = Not Applicable
+{{% else %}}
+# platform = multi_platform_all
+{{% endif %}}
 
 SSHD_PARAM="RekeyLimit"
 
