@@ -2,4 +2,4 @@
 # variables = var_password_hashing_min_rounds_login_defs=5000
 
 # Default values are 5000 if the parameters are not defined.
-truncate -s 0 "/etc/login.defs"
+truncate -s 0 {{{ login_defs_path }}}
