@@ -1,14 +1,14 @@
 #!/bin/bash
 
 useradd --system --shell /sbin/nologin -u 999 sysuser
-useradd -u 1000 testuser
+useradd -u {{{ uid_min }}} testuser
 
 key=UID_MIN
 
 # Add key as 1st line, drop others
 sed -Ei '
 1{i\
-'"$key"' 1000
+'"$key"' {{{ uid_min }}}
 }
 /^(SYS_)?UID_(MIN|MAX)/d;
-' /etc/login.defs
+' {{{ login_defs_path }}}
