@@ -1,5 +1,9 @@
 #!/bin/bash
 
+{{% if 'ubuntu' in product %}}
+# platform = Not Applicable
+{{% endif %}}
+
 # variables = var_accounts_tmout=900
 
 TEST_FILE=/etc/profile.d/tmout.sh
