@@ -3,4 +3,5 @@
 USER="cac_user"
 useradd -m $USER
 touch /home/$USER/.bashrc
-chgrp $USER /home/$USER/.bashrc
+GROUP=$(id $USER -g)
+chgrp -f $GROUP /home/$USER/.bashrc
