@@ -3,4 +3,4 @@
 USER="cac_user"
 useradd -m $USER
 echo "$USER" > /home/$USER/$USER.txt
-chmod -Rf 750 /home/$USER/.*
+find "/home/$USER/" -perm /7027 -exec chmod u-s,g-w-s,o=- {} \;
