@@ -9,7 +9,7 @@
 ipv4_rule='rule family=ipv4 source address="127.0.0.1" destination not address="127.0.0.1" drop'
 ipv6_rule='rule family=ipv6 source address="::1" destination not address="::1" drop'
 
-if {{{ in_chrooted_environment }}} || {{{ bash_bootc_build() }}}; then
+if {{{ in_chrooted_environment() }}} || {{{ bash_bootc_build() }}}; then
     firewall-offline-cmd --zone=trusted --add-rich-rule="${ipv4_rule}"
     firewall-offline-cmd --zone=trusted --add-rich-rule="${ipv6_rule}"
 elif systemctl is-active firewalld; then
