@@ -1,5 +1,5 @@
 #!/bin/bash
-{{% if product in ['rhel9'] %}}
+{{% if product in ['rhel9','ol9'] %}}
 # variables = var_mount_option_proc_hidepid=invisible
 {{% else %}}
 # variables = var_mount_option_proc_hidepid=2
