@@ -1,7 +1,7 @@
 #!/bin/bash
-{{% if 'sle' in product %}}
+{{% if 'sle' in product or 'slmicro' in product %}}
 # packages = libselinux1
-{{% else %}} 
+{{% else %}}
 # packages = python3-libselinux
 {{% endif %}}
 
