@@ -4,7 +4,11 @@
 {{% endif %}}
 
 # Clean sysctl config directories
+{{% if "ubuntu" in product %}}
+rm -rf /usr/lib/sysctl.d/* /run/sysctl.d/* /etc/sysctl.d/* /etc/ufw/sysctl.conf
+{{% else %}}
 rm -rf /usr/lib/sysctl.d/* /run/sysctl.d/* /etc/sysctl.d/*
+{{% endif %}}
 
 sed -i "/{{{ SYSCTLVAR }}}/d" /etc/sysctl.conf
 
