@@ -1,11 +1,18 @@
 #!/bin/bash
+{{%- if NO_REMEDIATION %}}
+# remediation = none
+{{%- endif -%}}
 {{% if SYSCTLVAL == "" %}}
 # variables = sysctl_{{{ SYSCTLID }}}_value={{{ SYSCTL_CORRECT_VALUE }}}
 {{% endif %}}
 
 # Clean sysctl config directories
-{{% if product not in ["sle12", "sle15", "slmicro5"] %}}
+{{% if product not in ["sle12", "sle15", "slmicro5", "slmicro6"] %}}
+{{% if "ubuntu" in product %}}
+rm -rf /usr/lib/sysctl.d/* /run/sysctl.d/* /etc/sysctl.d/* /etc/ufw/sysctl.conf
+{{% else %}}
 rm -rf /usr/lib/sysctl.d/* /run/sysctl.d/* /etc/sysctl.d/*
+{{% endif %}}
 
 sed -i "/{{{ SYSCTLVAR }}}/d" /etc/sysctl.conf
 mkdir -p /usr/local/lib/sysctl.d
