@@ -9,11 +9,11 @@ from collections import defaultdict, namedtuple, OrderedDict
 
 import ssg.yaml
 import ssg.build_yaml
+import ssg.jinja
 from . import rules
 from . import utils
 
 from . import constants
-from .jinja import process_file_with_macros as jinja_process_file
 
 from .xml import ElementTree
 from .constants import XCCDF12_NS
@@ -26,7 +26,8 @@ REMEDIATION_TO_EXT_MAP = {
     'ignition': '.yml',
     'kubernetes': '.yml',
     'blueprint': '.toml',
-    'kickstart': '.cfg'
+    'kickstart': '.cfg',
+    'bootc': '.bo'
 }
 
 
@@ -90,7 +91,7 @@ def parse_from_file_with_jinja(file_path, env_yaml):
     update ssg.fixes.parse_platform(...).
     """
 
-    fix_file = jinja_process_file(file_path, env_yaml)
+    fix_file = ssg.jinja.process_file(file_path, env_yaml)
     return split_remediation_content_and_metadata(fix_file)
 
 
@@ -127,8 +128,11 @@ class Remediation(object):
         self.local_env_yaml["rule_id"] = self.associated_rule.id_
         self.local_env_yaml["cce_identifiers"] = self.associated_rule.identifiers
 
-    def parse_from_file_with_jinja(self, env_yaml, cpe_platforms):
-        return parse_from_file_with_jinja(self.file_path, env_yaml)
+    def parse_from_file(self, env_yaml, cpe_platforms):
+        if "fixes_from_templates" in self.file_path:
+            return parse_from_file_without_jinja(self.file_path)
+        else:
+            return parse_from_file_with_jinja(self.file_path, env_yaml)
 
     def get_inherited_cpe_platform_names(self):
         inherited_cpe_platform_names = set()
@@ -187,7 +191,7 @@ def process(remediation, env_yaml, cpe_platforms):
     if not is_supported_filename(remediation.remediation_type, remediation.file_path):
         return
 
-    result = remediation.parse_from_file_with_jinja(env_yaml, cpe_platforms)
+    result = remediation.parse_from_file(env_yaml, cpe_platforms)
     platforms = result.config['platform']
 
     if not platforms:
@@ -214,9 +218,9 @@ class BashRemediation(Remediation):
     def __init__(self, file_path):
         super(BashRemediation, self).__init__(file_path, "bash")
 
-    def parse_from_file_with_jinja(self, env_yaml, cpe_platforms):
+    def parse_from_file(self, env_yaml, cpe_platforms):
         self.local_env_yaml.update(env_yaml)
-        result = super(BashRemediation, self).parse_from_file_with_jinja(
+        result = super(BashRemediation, self).parse_from_file(
             self.local_env_yaml, cpe_platforms)
 
         # Avoid platform wrapping empty fix text
@@ -265,9 +269,9 @@ class AnsibleRemediation(Remediation):
 
         self.body = None
 
-    def parse_from_file_with_jinja(self, env_yaml, cpe_platforms):
+    def parse_from_file(self, env_yaml, cpe_platforms):
         self.local_env_yaml.update(env_yaml)
-        result = super(AnsibleRemediation, self).parse_from_file_with_jinja(
+        result = super(AnsibleRemediation, self).parse_from_file(
             self.local_env_yaml, cpe_platforms)
 
         if not self.associated_rule:
@@ -468,6 +472,15 @@ class KickstartRemediation(Remediation):
             file_path, "kickstart")
 
 
+class BootcRemediation(Remediation):
+    """
+    This provides class for Bootc remediations
+    """
+    def __init__(self, file_path):
+        super(BootcRemediation, self).__init__(
+            file_path, "bootc")
+
+
 REMEDIATION_TO_CLASS = {
     'anaconda': AnacondaRemediation,
     'ansible': AnsibleRemediation,
@@ -477,6 +490,7 @@ REMEDIATION_TO_CLASS = {
     'kubernetes': KubernetesRemediation,
     'blueprint': BlueprintRemediation,
     'kickstart': KickstartRemediation,
+    'bootc': BootcRemediation,
 }
 
 
@@ -537,7 +551,7 @@ def get_rule_dir_remediations(dir_path, remediation_type, product=None):
                 # Here, the filename is a subset of the product, but isn't
                 # the full product. Product here is both the product name
                 # (e.g., ubuntu) and its version (2004). Filename could be
-                # either "ubuntu" or "ubuntu2004" so we want this branch
+                # either "ubuntu" or "ubuntu2404" so we want this branch
                 # to trigger when it is the former, not the latter. It is
                 # the highest priority of common results, so insert it
                 # before any shared ones.
@@ -616,6 +630,8 @@ def expand_xccdf_subs(fix, remediation_type):
         pattern = r'\(bash-populate\s*(\S+)\)'
     elif remediation_type == "kickstart":
         pattern = r'\(kickstart-populate\s*(\S+)\)'
+    elif remediation_type == "bootc":
+        pattern = r'\(bootc-populate\s*(\S+)\)'
     else:
         sys.stderr.write("Unknown remediation type '%s'\n" % (remediation_type))
         sys.exit(1)
