@@ -8,14 +8,15 @@ from .constants import (
     OSCAP_RULE, OSCAP_VALUE, oval_namespace, XCCDF12_NS, cce_uri, ocil_cs,
     ocil_namespace, OVAL_TO_XCCDF_DATATYPE_CONSTRAINTS
 )
+from . import utils
 from .xml import parse_file, map_elements_to_their_ids
-from .oval_object_model import load_oval_document
-
+from .oval_object_model import load_oval_document, OVALDefinitionReference
 
 from .checks import get_content_ref_if_exists_and_not_remote
 from .cce import is_cce_value_valid, is_cce_format_valid
 from .utils import SSGError
 from .xml import ElementTree as ET
+
 oval_ns = oval_namespace
 oval_cs = oval_namespace
 
@@ -30,14 +31,14 @@ class FileLinker(object):
 
     def __init__(self, translator, xccdftree, checks, output_file_name):
         self.translator = translator
-        self.checks_related_to_us = self._get_related_checks(checks)
+        self.checks_related_to_us = self.get_related_checks(checks)
         self.fname = self._get_input_fname()
         self.tree = None
         self.linked_fname = output_file_name
         self.linked_fname_basename = os.path.basename(self.linked_fname)
         self.xccdftree = xccdftree
 
-    def _get_related_checks(self, checks):
+    def get_related_checks(self, checks):
         """
         Returns a list of checks which have the same check system as this
         class.
@@ -79,7 +80,9 @@ class FileLinker(object):
         """
         assert self.tree is not None, \
             "There is no tree to save, you have probably skipped the linking phase"
-        ET.ElementTree(self.tree).write(self.linked_fname)
+        if hasattr(ET, "indent"):
+            ET.indent(self.tree, space="  ", level=0)
+        ET.ElementTree(self.tree).write(self.linked_fname, xml_declaration=True, encoding="utf-8")
 
     def _get_checkid_string(self):
         raise NotImplementedError()
@@ -88,6 +91,7 @@ class FileLinker(object):
         pass
 
     def link_xccdf(self):
+
         for check in self.checks_related_to_us:
             checkcontentref = get_content_ref_if_exists_and_not_remote(check)
             if checkcontentref is None:
@@ -115,6 +119,7 @@ class FileLinker(object):
 class OVALFileLinker(FileLinker):
     CHECK_SYSTEM = oval_cs
     CHECK_NAMESPACE = oval_ns
+    build_ovals_dir = None
 
     def __init__(self, translator, xccdftree, checks, output_file_name):
         super(OVALFileLinker, self).__init__(
@@ -127,6 +132,34 @@ class OVALFileLinker(FileLinker):
     def _translate_name_to_oval_definition_id(self, name):
         return self.translator.generate_id(self._get_checkid_string(), name)
 
+    def _get_path_for_oval_document(self, name):
+        if self.build_ovals_dir:
+            utils.mkdir_p(self.build_ovals_dir)
+        return os.path.join(self.build_ovals_dir, name + ".xml")
+
+    def _get_list_of_names_of_oval_checks(self):
+        out = []
+        for _, rule in rules_with_ids_generator(self.xccdftree):
+            for check in rule.findall(".//{%s}check" % (XCCDF12_NS)):
+                checkcontentref = get_content_ref_if_exists_and_not_remote(check)
+                if checkcontentref is None or check.get("system") != oval_cs:
+                    continue
+                out.append(checkcontentref.get("name"))
+        return out
+
+    def save_oval_document_for_each_xccdf_rule(self, file_name_prefix=""):
+        for name in self._get_list_of_names_of_oval_checks():
+            if name in self.oval_document.definitions:
+                oval_def = self.oval_document.definitions[name]
+                name = oval_def.name
+
+            oval_id = self._translate_name_to_oval_definition_id(name)
+
+            refs = self.oval_document.get_all_references_of_definition(oval_id)
+            path = self._get_path_for_oval_document(file_name_prefix + name)
+            with open(path, "wb+") as fd:
+                self.oval_document.save_as_xml(fd, refs)
+
     def save_linked_tree(self):
         """
         Write internal tree to the file in self.linked_fname.
@@ -134,6 +167,9 @@ class OVALFileLinker(FileLinker):
         with open(self.linked_fname, "wb+") as fd:
             self.oval_document.save_as_xml(fd)
 
+        if self.build_ovals_dir:
+            self.save_oval_document_for_each_xccdf_rule()
+
     def link(self):
         self.oval_document = load_oval_document(parse_file(self.fname))
         self.oval_document.product_name = "OVALFileLinker"
@@ -161,6 +197,7 @@ class OVALFileLinker(FileLinker):
         # Verify all by XCCDF referenced (local) OVAL checks are defined in OVAL file
         # If not drop the <check-content> OVAL checksystem reference from XCCDF
         self._ensure_by_xccdf_referenced_oval_def_is_defined_in_oval_file()
+        self._ensure_by_xccdf_referenced_oval_no_extra_def_in_oval_file()
 
         check_and_correct_xccdf_to_oval_data_export_matching_constraints(
             self.xccdftree, self.oval_document
@@ -238,6 +275,21 @@ class OVALFileLinker(FileLinker):
                 # * But not defined in OVAL file
                 rule.remove(check)
 
+    def _ensure_by_xccdf_referenced_oval_no_extra_def_in_oval_file(self):
+        # Remove all OVAL checks that are not referenced by XCCDF Rules (checks)
+        # or internally via extend-definition
+
+        xccdf_oval_check_refs = self._get_list_of_names_of_oval_checks()
+        document_def_keys = list(self.oval_document.definitions.keys())
+
+        references_from_xccdf_to_keep = OVALDefinitionReference()
+        for def_id in document_def_keys:
+            if def_id in xccdf_oval_check_refs:
+                oval_def_refs = self.oval_document.get_all_references_of_definition(def_id)
+                references_from_xccdf_to_keep += oval_def_refs
+
+        self.oval_document.keep_referenced_components(references_from_xccdf_to_keep)
+
 
 class OCILFileLinker(FileLinker):
     CHECK_SYSTEM = ocil_cs
