@@ -11,17 +11,19 @@ import os
 import os.path
 import re
 import shutil
-import subprocess
 import tempfile
 
+import ssg.utils
 from ssg.constants import OSCAP_PROFILE, OSCAP_PROFILE_ALL_ID, OSCAP_RULE
-from ssg_test_suite import oscap
-from ssg_test_suite import xml_operations
-from ssg_test_suite import test_env
-from ssg_test_suite import common
-from ssg_test_suite.log import LogHelper
+from ssg.jinja import process_file
+from ssg.rules import is_rule_dir
+
+from tests.ssg_test_suite import oscap
+from tests.ssg_test_suite import xml_operations
+from tests.ssg_test_suite import test_env
+from tests.ssg_test_suite import common
+from tests.ssg_test_suite.log import LogHelper
 
-import ssg.templates
 
 Rule = collections.namedtuple(
     "Rule",
@@ -157,6 +159,7 @@ class RuleChecker(oscap.Checker):
                 return False
             if initial_scan_res == 2:
                 # notapplicable
+                self.initial_scan_result = 2
                 return True
 
             supported_and_available_remediations = self._get_available_remediations(scenario)
@@ -302,7 +305,7 @@ class RuleChecker(oscap.Checker):
 
         for dirpath, dirnames, filenames in common.walk_through_benchmark_dirs(
                 product):
-            if not common.is_rule_dir(dirpath):
+            if not is_rule_dir(dirpath):
                 continue
             short_rule_id = os.path.basename(dirpath)
             full_rule_id = OSCAP_RULE + short_rule_id
@@ -322,17 +325,6 @@ class RuleChecker(oscap.Checker):
             rule, local_env_yaml = common.load_rule_and_env(
                 dirpath, product_yaml, product)
 
-            # Before we get too far, we wish to search the rule YAML to see if
-            # it is applicable to the current product. If we have a product
-            # and the rule isn't applicable for the product, there's no point
-            # in continuing with the rest of the loading. This should speed up
-            # the loading of the templated tests. Note that we've already
-            # parsed the prodtype into local_env_yaml
-            if product and local_env_yaml['products']:
-                prodtypes = local_env_yaml['products']
-                if "all" not in prodtypes and product not in prodtypes:
-                    continue
-
             tests_dir = os.path.join(dirpath, "tests")
             template_name = None
             if rule.template and rule.template['vars']:
@@ -417,6 +409,7 @@ class RuleChecker(oscap.Checker):
         return all_tests
 
     def _get_rule_test_content(self, rule):
+        checks = xml_operations.find_checks_in_rule(self.datastream, self.benchmark_id, rule.id)
         all_tests = self._load_all_tests(rule)
         scenarios = []
         other_content = dict()
@@ -425,13 +418,28 @@ class RuleChecker(oscap.Checker):
             if re.search(scenario_matches_regex, file_name):
                 scenario = Scenario(file_name, file_content)
                 scenario.override_profile(self.scenarios_profile)
-                if scenario.matches_regex_and_platform(
-                        self.scenarios_regex, self.benchmark_cpes):
+                if scenario.matches_regex_and_check_and_platform(
+                        self.scenarios_regex, checks, self.test_env.product):
                     scenarios.append(scenario)
             else:
                 other_content[file_name] = file_content
         return RuleTestContent(scenarios, other_content)
 
+    def _get_shared_test_content(self):
+        product_yaml = common.get_product_context(self.test_env.product)
+        other_content = dict()
+        for dirpath, _, filenames in os.walk(common._SHARED_DIR):
+            for file_name in filenames:
+                file_path = os.path.join(dirpath, file_name)
+                rel_path = os.path.relpath(file_path, common._SHARED_DIR)
+                try:
+                    file_content = process_file(file_path, product_yaml)
+                except Exception as e:
+                    logging.error("Error processing file {0}: {1}".format(file_path, str(e)))
+                    continue
+                other_content[rel_path] = file_content
+        return RuleTestContent([], other_content)
+
     def _get_test_content_by_rule_id(self, rules_to_test):
         test_content_by_rule_id = dict()
         for rule in rules_to_test:
@@ -439,6 +447,7 @@ class RuleChecker(oscap.Checker):
             test_content_by_rule_id[rule.id] = rule_test_content
         sliced_test_content_by_rule_id = self._slice_sbr(
             test_content_by_rule_id, self.slice_current, self.slice_total)
+        sliced_test_content_by_rule_id["shared"] = self._get_shared_test_content()
         return sliced_test_content_by_rule_id
 
     def _test_target(self):
@@ -447,9 +456,6 @@ class RuleChecker(oscap.Checker):
         if not self.rule_spec:
             source = self.template_spec
         if not rules_to_test:
-            logging.error("No tests found matching the {0}(s) '{1}'".format(
-                self.target_type,
-                ", ".join(source)))
             return
 
         test_content_by_rule_id = self._get_test_content_by_rule_id(
@@ -487,6 +493,8 @@ class RuleChecker(oscap.Checker):
         self._current_result.scenario = common.Scenario_run(rule_id, scenario.script)
         self._current_result.when = self.test_timestamp_str
 
+        if hasattr(self, 'initial_scan_result') and self.initial_scan_result == 2:
+            return
         with self.copy_of_datastream():
             self._check_rule_scenario(scenario, remote_rule_dir, rule_id, remediation_available)
         self.results.append(self._current_result.save_to_dict())
@@ -543,6 +551,13 @@ class RuleChecker(oscap.Checker):
 
 
     def _check_rule_scenario(self, scenario, remote_rule_dir, rule_id, remediation_available):
+        if "sce" in scenario.script_params["check"] and not self.test_env.sce_support:
+            logging.warning(
+                "Scenario {0} is used for SCE testing but OpenSCAP installed "
+                "on the back end doesn't support SCE. To test SCE, please "
+                "install the openscap-engine-sce package on the back end.".format(scenario.script)
+            )
+            return
         if not _apply_script(
                 remote_rule_dir, self.test_env, scenario.script):
             logging.error("Environment failed to prepare, skipping test")
@@ -597,6 +612,7 @@ class Scenario():
             'templates': [],
             'packages': [],
             'platform': ['multi_platform_all'],
+            'check': ['any'],
             'remediation': ['all'],
             'variables': [],
         }
@@ -644,22 +660,35 @@ class Scenario():
                 return False
         return True
 
-    def matches_platform(self, benchmark_cpes):
+    def matches_platform(self, product):
+        platform = ",".join(self.script_params["platform"])
         if self.context is None:
             return False
-        if common.matches_platform(
-                self.script_params["platform"], benchmark_cpes):
+        if ssg.utils.is_applicable_for_product(platform, product):
             return True
         else:
             logging.warning(
-                "Script %s is not applicable on given platform" %
-                self.script)
+                "Script '%s' is not applicable on '%s' target because its "
+                "platform is '%s'" % (self.script, product, platform))
             return False
 
-    def matches_regex_and_platform(self, scenarios_regex, benchmark_cpes):
+    def matches_check(self, rule_checks):
+        if "any" in self.script_params["check"]:
+            return True
+        for check in self.script_params["check"]:
+            if check in rule_checks:
+                return True
+        logging.warning(
+            "Script %s is not applicable for %s check type" %
+            (self.script, ", ".join(self.script_params['check'])))
+        return False
+
+
+    def matches_regex_and_check_and_platform(self, scenarios_regex, checks, product):
         return (
             self.matches_regex(scenarios_regex)
-            and self.matches_platform(benchmark_cpes))
+            and self.matches_check(checks)
+            and self.matches_platform(product))
 
 
 def perform_rule_check(options):
