@@ -45,10 +45,8 @@ def has_empty_identifier(rule_path, rule, rule_lines):
 
 
 def has_no_cce(yaml_file, product_yaml=None):
-    rule = yaml.open_and_macro_expand(yaml_file, product_yaml)
+    rule = yaml.open_and_expand(yaml_file, product_yaml)
     product = product_yaml["product"]
-    if "prodtype" in rule and product not in rule["prodtype"]:
-        return False
     if 'identifiers' in rule and rule['identifiers'] is None:
         return True
 
@@ -110,9 +108,16 @@ def has_duplicated_subkeys(rule_path, rule, rule_lines):
     return ssg.rule_yaml.has_duplicated_subkeys(rule_path, rule_lines, TO_SORT)
 
 
+def _human_sort(line):
+    # Based on: https://blog.codinghorror.com/sorting-for-humans-natural-sort-order/
+    def convert(text): return int(text) if text.isdigit() else text
+    return [convert(text) for text in re.split(r'(\d+)', line)]
+
+
 def has_unordered_sections(rule_path, rule, rule_lines):
     if 'references' in rule or 'identifiers' in rule:
-        new_lines = ssg.rule_yaml.sort_section_keys(rule_path, rule_lines, TO_SORT)
+        new_lines = ssg.rule_yaml.sort_section_keys(rule_path, rule_lines, TO_SORT,
+                                                    sort_func=_human_sort)
 
         # Compare string representations to avoid issues with references being
         # different.
@@ -153,7 +158,7 @@ def rule_data_generator(args):
 
         rule_path = ssg.rules.get_rule_dir_yaml(rule_obj['dir'])
         try:
-            rule = yaml.open_and_macro_expand(rule_path, local_env_yaml)
+            rule = yaml.open_and_expand(rule_path, local_env_yaml)
             rule_lines = read_file_list(rule_path)
             yield rule_path, rule, rule_lines, product_path, local_env_yaml
         except jinja2.exceptions.UndefinedError as ue:
@@ -417,15 +422,6 @@ def fix_invalid_cce(file_contents, yaml_contents):
     return remove_section_keys(file_contents, yaml_contents, section, invalid_identifiers)
 
 
-def fix_prodtypes(file_contents, yaml_contents):
-    section = 'prodtype'
-    sorted_prodtypes = yaml_contents[section].split(",")
-    sorted_prodtypes.sort()
-    out = ",".join(sorted_prodtypes)
-
-    return rewrite_keyless_section(file_contents, yaml_contents, section, out)
-
-
 def has_product_cce(yaml_contents, product):
     section = 'identifiers'
 
@@ -480,7 +476,7 @@ def fix_int_reference(file_contents, yaml_contents):
 
 
 def sort_rule_subkeys(file_contents, yaml_contents):
-    return ssg.rule_yaml.sort_section_keys(None, file_contents, TO_SORT)
+    return ssg.rule_yaml.sort_section_keys(None, file_contents, TO_SORT, sort_func=_human_sort)
 
 
 def _fixed_file_contents(path, file_contents, product_yaml, func):
@@ -488,7 +484,7 @@ def _fixed_file_contents(path, file_contents, product_yaml, func):
         file_contents = file_contents[:-1]
 
     subst_dict = product_yaml
-    yaml_contents = yaml.open_and_macro_expand(path, subst_dict)
+    yaml_contents = yaml.open_and_expand(path, subst_dict)
 
     try:
         new_file_contents = func(file_contents, yaml_contents)
@@ -586,13 +582,6 @@ def _add_cce(directory, cce_pool, rules, product_yaml, args):
             cce_pool.remove_cce_from_file(cce)
 
 
-def has_unsorted_prodtype(rule_path, rule, rule_lines):
-    if 'prodtype' in rule:
-        prodtypes = rule['prodtype'].split(',')
-        return prodtypes != sorted(prodtypes)
-    return False
-
-
 @command("empty_identifiers", "check and fix rules with empty identifiers")
 def fix_empty_identifiers(args, product_yaml):
     results = find_rules(args, has_empty_identifier)
@@ -696,7 +685,7 @@ def find_int_references(args, product_yaml):
         product_yaml = result[2]
 
         if args.dry_run:
-            print(rule_path + " has one or more unsorted references")
+            print(rule_path + " has one or more unsorted integer references")
             continue
 
         fix_file_prompt(rule_path, product_yaml, fix_int_reference, args)
@@ -733,22 +722,6 @@ def sort_subkeys(args, product_yaml):
     exit(int(len(results) > 0))
 
 
-@command("sort_prodtypes", "sorts the products in the prodtype")
-def sort_prodtypes(args, product_yaml):
-    results = find_rules(args, has_unsorted_prodtype)
-    for result in results:
-        rule_path = result[0]
-        product_yaml = result[2]
-
-        if args.dry_run:
-            print(rule_path + " prodtype is unsorted")
-            continue
-
-        fix_file(rule_path, product_yaml, fix_prodtypes)
-
-    exit(int(len(results) > 0))
-
-
 @command("test_all", "Perform all checks on all rules")
 def test_all(args, product_yaml):
     result = 0
@@ -759,8 +732,7 @@ def test_all(args, product_yaml):
         (has_empty_references, "empty references"),
         (has_int_reference, "unsorted references"),
         (has_duplicated_subkeys, "duplicated subkeys"),
-        (has_unordered_sections, "unsorted references"),
-        (has_unsorted_prodtype, "unsorted prodtype")
+        (has_unordered_sections, "unsorted references")
     ]
     for item in rule_data_generator(args):
         rule_path, rule, rule_lines, _, _ = item
