@@ -11,7 +11,7 @@ Script created to help maintainers during the release process by automating Gith
 # - https://pygithub.readthedocs.io/en/latest/github_objects.html
 # - https://docs.github.com/en/rest
 
-from datetime import datetime, timedelta, UTC
+from datetime import datetime, timedelta, UTC, date
 
 from github import Github
 import argparse
@@ -96,24 +96,16 @@ def get_repo_stable_branch(repo) -> object:
     branches = get_repo_branches(repo)
     return filter_repo_branch_by_name(branches, "stable")
 
-
-def get_old_stabilization_branch(repo) -> object:
-    branches = get_repo_branches(repo)
-    latest_version = get_latest_version(repo)
-    branch_name = f'stabilization-v{latest_version}'
-    return filter_repo_branch_by_name(branches, branch_name)
-
-
-def remove_old_stabilization_branch(repo, branch) -> None:
-    if get_confirmation(f'Are you sure about removing the "{branch.name}" branch?'):
+def remove_old_stabilization_branch(repo) -> None:
+    if get_confirmation('Are you sure about removing the "stabilization" branch?'):
         # https://github.com/PyGithub/PyGithub/issues/1570
         try:
-            branch_ref = repo.get_git_ref(f'heads/{branch.name}')
+            branch_ref = repo.get_git_ref('heads/stabilization')
             branch_ref.delete()
         except Exception as e:
             print(f'Error: {e}')
     else:
-        print(f'Aborted! {branch.name} branch not removed.')
+        print(f'Aborted! stabilization branch not removed.')
 
 
 # Repository Contributors
@@ -140,8 +132,8 @@ def get_contributors_last_update() -> str:
         # This comment informs when the file was updated.
         if 'Last Modified:' in line:
             elements = line.split('{+')
-            datetime = elements[1].replace('+}', '')
-            return datetime
+            last_modified_date_time = elements[1].replace('+}', '')
+            return last_modified_date_time
 
 
 def get_new_contributors(commit) -> str:
@@ -157,10 +149,10 @@ def get_new_contributors(commit) -> str:
 
 
 def is_contributors_list_updated(date_string) -> bool:
-    date = datetime.strptime(date_string[:16], '%Y-%m-%d %H:%M')
+    date = datetime.strptime(date_string[:16], '%Y-%m-%d %H:%M').replace(tzinfo=UTC)
     # As a rule of thumbs, this function consider contributors list
     # updated if not older than 2 weeks.
-    two_weeks_back = datetime.now() - timedelta(days=15)
+    two_weeks_back = datetime.now(tz=UTC) - timedelta(days=15)
     if date < two_weeks_back:
         return False
     return True
@@ -336,33 +328,31 @@ def get_monday_that_follows(date) -> datetime:
     return date + timedelta((0 - date.weekday()) % 7)
 
 
-def get_next_quarter_first_month(latest_release_date: datetime) -> int:
+def get_next_quarter_second_month(latest_release_date: datetime) -> int:
     last_release_quarter = (latest_release_date.month - 1) // 3 + 1
     if last_release_quarter == 4:
         next_release_quarter = 1
     else:
         next_release_quarter = last_release_quarter + 1
-    return (next_release_quarter - 1) * 3 + 1
+    return (next_release_quarter - 1) * 3 + 2
 
 
-def get_last_monday_of_month(year: int, month: int) -> datetime:
-    if month == 12:
-        last_month_day = datetime(year, month, 31)
-    else:
-        last_month_day = datetime(year, month + 1, 1) - timedelta(days=1)
-
-    days_since_monday = (last_month_day.weekday() - 0) % 7
-    return last_month_day - timedelta(days=days_since_monday)
+def get_third_monday_of_month(year: int, month: int) -> datetime:
+    first_day_of_month = date(year, month, 1)
+    first_day_weekday = first_day_of_month.weekday()
+    first_monday_date = 1 + (0 - first_day_weekday) % 7
+    third_monday_date = first_monday_date + 14
+    return datetime(year, month, third_monday_date, tzinfo=UTC)
 
 
-def get_next_stabilization_date(release_date) -> datetime:
+def get_next_stabilization_date(release_date: datetime) -> datetime:
     two_weeks_before = release_date - timedelta(weeks=2)
     stabilization_monday = get_monday_that_follows(two_weeks_before)
     return stabilization_monday.date()
 
 
 def get_next_release_date(latest_release_date: datetime) -> datetime:
-    month = get_next_quarter_first_month(latest_release_date)
+    month = get_next_quarter_second_month(latest_release_date)
     now = datetime.now(UTC)
 
     if month > 9 and latest_release_date <= now:
@@ -370,12 +360,12 @@ def get_next_release_date(latest_release_date: datetime) -> datetime:
     else:
         year = latest_release_date.year
 
-    last_monday = get_last_monday_of_month(year, month)
-    return get_friday_that_follows(last_monday + timedelta(weeks=1))
+    third_monday = get_third_monday_of_month(year, month)
+    return get_friday_that_follows(third_monday + timedelta(weeks=1))
 
 
 def is_next_release_in_progress(repo) -> bool:
-    stabilization_branch = get_next_stabilization_branch(repo)
+    stabilization_branch = "stabilization"
     branches_names = [branch.name for branch in get_repo_branches(repo)]
     if stabilization_branch in branches_names:
         return True
@@ -388,12 +378,6 @@ def get_next_release_version(repo) -> str:
     next_version = bump_version(current_version, 'minor')
     return next_version
 
-
-def get_next_stabilization_branch(repo) -> str:
-    next_release = get_next_release_version(repo)
-    return f'stabilization-v{next_release}'
-
-
 # Communication
 def get_date_for_message(date) -> datetime:
     return date.strftime("%B %d, %Y")
@@ -423,7 +407,7 @@ def get_release_start_message(repo) -> str:
     next_release_version = get_next_release_version(repo)
     next_release_date = get_next_release_date(latest_release.published_at)
     date = get_date_for_message(next_release_date)
-    branch = get_next_stabilization_branch(repo)
+    branch = "stabilization"
 
     future_version = bump_version(next_release_version, 'minor')
     future_release_date = get_next_release_date(next_release_date)
@@ -602,13 +586,13 @@ def collect_release_info(repo) -> dict:
     data["latest_version"] = get_latest_version(repo)
 
     next_release_date = get_next_release_date(latest_release.published_at)
-    next_release_remaining_days = next_release_date - datetime.today()
+    next_release_remaining_days = next_release_date - datetime.now(tz=UTC)
     data["next_release_date"] = next_release_date
     data["next_release_remaining_days"] = next_release_remaining_days.days
     data["next_release_state"] = describe_next_release_state(repo)
     data["next_release_version"] = get_next_release_version(repo)
     next_stabilization_date = get_next_stabilization_date(next_release_date)
-    next_stabilization_remaining_days = next_stabilization_date - datetime.today().date()
+    next_stabilization_remaining_days = next_stabilization_date - datetime.now(tz=UTC).date()
     data["next_stabilization_date"] = next_stabilization_date
     data["next_stabilization_remaining_days"] = next_stabilization_remaining_days.days
 
@@ -651,7 +635,7 @@ def print_last_release_stats(data):
 
 
 def print_next_release_stats(data):
-    now = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
+    now = datetime.now(tz=UTC).strftime("%Y-%m-%d %H:%M:%S%z")
     milestone = data['active_milestone']
     next_release_version = data['next_release_version']
     next_release_date = data['next_release_date']
@@ -684,13 +668,7 @@ def stats(repo, args):
 
 def cleanup(repo, args) -> None:
     if args.branch:
-        branches_to_remove = get_old_stabilization_branch(repo)
-        if branches_to_remove:
-            for branch in branches_to_remove:
-                remove_old_stabilization_branch(repo, branch)
-        else:
-            print('Great! There is no branch to be removed.')
-
+        remove_old_stabilization_branch(repo)
 
 def release_prep(repo, args) -> None:
     if args.contributors:
@@ -723,15 +701,6 @@ def release_prep(repo, args) -> None:
 
 def release(repo, args) -> None:
     if is_next_release_in_progress(repo):
-        if args.tag:
-            next_version = get_next_release_version(repo)
-            tag_name = f'v{next_version}'
-            stab_branch = get_next_stabilization_branch(repo)
-            print('Release process starts when a version tag is added to the branch.\n'
-                  'It is better to do it manually. But here are the commands you need:\n')
-            print(f'git tag {tag_name} {stab_branch}\n'
-                  'git push --tags')
-
         if args.message:
             message = get_release_start_message(repo)
             print_communication_channels('release')
@@ -796,9 +765,6 @@ def parse_arguments():
     release_parser.add_argument(
         '-m', '--message', action='store_true',
         help="Prepare a message to communicate the stabilization process has started.")
-    release_parser.add_argument(
-        '-t', '--tag', action='store_true',
-        help="Show commands to properly tag the branch and start the release.")
 
     finish_parser = subparsers.add_parser(
         'finish', help="Tasks to be done when the release is out.")
